==> lms-1.4.5+libs.tar.gz: lms/contrib/customer_otherip/balanceview.php <==
<?

/*
 * LMS version 1.4.5 Persus
 *
 *  (C) Copyright 2001-2005 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: balanceview.php,v 1.3.2.4 2005/01/01 19:19:07 alec Exp $
 */

$layout['pagetitle'] = 'Panel uytkownika';

include_once('class.php');
include_once('authentication.inc');

$loginform = $_POST['loginform'];
$login = ($loginform['login'] ? $loginform['login'] : 0);
$pin = ($loginform['pwd'] ? $loginform['pwd'] : 0);

//sposoby autoryzacji uytkownika
$id = GetUserIDByPhone1AndPIN($login, $pin);
//$id = GetUserIDByContractAndPIN($login, $pin);
//$id = GetUserIDByIDAndPIN($login, $pin);

if($id)
{
	$SMARTY->assign('user',$LMS->GetUser($id));
	$SMARTY->assign('userinfo',$LMS->GetUser($id));
	$SMARTY->assign('balancelist',$LMS->GetUserBalanceList($id));
	$SMARTY->assign('limit',15);
	$SMARTY->display('balanceview.html');
}
else
	header('Location: index.php?error=1');

?>

==> lms-1.6.1+libs.tar.gz: lms/contrib/customer_otherip/balanceview.php <==
<?

/*
 * LMS version 1.6.1 Ishta
 *
 *  (C) Copyright 2001-2005 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: balanceview.php,v 1.10.2.2 2005/06/21 11:31:12 alec Exp $
 */

include_once('class.php');
include_once('authentication.inc');

$layout['pagetitle'] = trans('Customer Logon');

$loginform = $_POST['loginform'];
$login = ($loginform['login'] ? trim($loginform['login']) : 0);
$pin = ($loginform['pwd'] ? trim($loginform['pwd']) : 0);

// customer authorization ways
//$id = GetUserIDByPhone1AndPIN($login, $pin);
//$id = GetUserIDByContractAndPIN($login, $pin);
$id = GetUserIDByIDAndPIN($login, $pin);

if($id)
{
	session_start();
	$_SESSION['uid'] = $id;

	$SMARTY->assign('userinfo',$LMS->GetUser($id));
	$SMARTY->assign('balancelist',$LMS->GetUserBalanceList($id));
	$SMARTY->assign('limit',15);
	$SMARTY->display('balanceview.html');
}
else
	header('Location: index.php?error=1');

?>
